About the competition
*********************

We are running a volunteery competition, there is no prize except topping the ranking below.

Implement your oversampling technique in terms of the ``smote_variants`` package (check the page :ref:`new_oversampler`), evaluate locally against the best performers, and if the results are convincing, send us or merge your code into the package. We'll repeat the testing and rank your oversampler according to the results.
